* ----------------------------------------------------------------------------------
* Which donors, which funds?
* Linear probability models in SURE specification 
* This version: September 22, 2016
* ----------------------------------------------------------------------------------

* Preliminaries
* -------------------------------------------------------------------------------

use "ReplicationData", clear

  * Donor-fund dyadic structure
  * TFs support substantive issue areas (no balance accounts)

global X cova g8_pledge global FCS MIC unemploym 

qui xi:reg isDonor i.ccode i.start_fy, nocon 
gen _Iccode_1=ccode==1
order _Iccode_1, before( _Iccode_2)
replace _Istart_fy_1990=1 if _Istart_fy_1986==1 |_Istart_fy_1987==1 |_Istart_fy_1988==1

global ctr  _Iccode_1-_Iccode_24 _Istart_fy_1990-_Istart_fy_2013



* Main regressions
* ------------------------------------------------------------------------------------

* 1) Relevant independent variables only
quietly reg isDonor $X if sdtf==1 & execution!="BETF"
est store SDTF_1
	predict isDonorhat1, xb
	g pos1=(isDonorhat1>=0.03355882)
	tab pos1 isDonor if sdtf==1 & execution!="BETF", co  
	* 77.4  40.7
quietly reg isDonor $X if mdtf4==1 & execution!="BETF"
est store MDTF4_1
	predict isDonorhat2, xb
	g pos2=(isDonorhat2>=0.08348268)
	tab pos2 isDonor if mdtf4==1 & execution!="BETF", co  
	* 73.1  42.3
quietly reg isDonor $X if umbr==1 & execution!="BETF"
est store UMBR_1
	predict isDonorhat3, xb
	g pos3=(isDonorhat3>=0.3237)
	tab pos3 isDonor if umbr==1 & execution!="BETF", co  
	* 65.3   51.4
qui suest SDTF_1 MDTF4_1 UMBR_1, cluster(ccode) ro
est tab SDTF_1 MDTF4_1 UMBR_1, star(.1 .05 .01) stats(N N_clust r2_a) b(%7.3f)
estout SDTF_1 MDTF4_1 UMBR_1, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop() mlab(,) 

	* Wald tests --  "difference" / "p-value" / "significance of one-sided t-test"
	** cova (SDTF-MDTF>0)
	test [SDTF_1_mean]cova = [MDTF4_1_mean]cova
	di [SDTF_1_mean]cova-[MDTF4_1_mean]cova
	* -0.0045 / 0.8198 / 0.590 (though p=0.41 is the error with which I reject H0:diff>0)
	test [SDTF_1_mean]cova = [UMBR_1_mean]cova  
	di [SDTF_1_mean]cova -[UMBR_1_mean]cova  
	* 0.1543 / 0.0000 / 0.000
	test [MDTF4_1_mean]cova = [UMBR_1_mean]cova 
	di [MDTF4_1_mean]cova -[UMBR_1_mean]cova 
	* 0.1588 / 0.0001 / 0.000
	
	** MIC (SDTF-MDTF>0)
	test [SDTF_1_mean]MIC = [MDTF4_1_mean]MIC  
	di [SDTF_1_mean]MIC - [MDTF4_1_mean]MIC  
	* 0.0444 / 0.7201 / 0.360
	test [SDTF_1_mean]MIC = [UMBR_1_mean]MIC  
	di [SDTF_1_mean]MIC - [UMBR_1_mean]MIC  
	* 0.087 / 0.0000 / 0.000
	test [MDTF4_1_mean]MIC = [UMBR_1_mean]MIC  
	di [MDTF4_1_mean]MIC - [UMBR_1_mean]MIC  
	* 0.0828 / 0.0009 / 0.000

	** unemploym (SDTF-MDTF>0)
	test [SDTF_1_mean]unemploym = [MDTF4_1_mean]unemploym  
	di [SDTF_1_mean]unemploym -[MDTF4_1_mean]unemploym  
	* 0.0053 / 0.067 / 0.034
	test [SDTF_1_mean]unemploym = [UMBR_1_mean]unemploym   
	di [SDTF_1_mean]unemploym - [UMBR_1_mean]unemploym   
	* 0.011 / 0.225 / 0.113
	test [MDTF4_1_mean]unemploym = [UMBR_1_mean]unemploym  
	di [MDTF4_1_mean]unemploym -[UMBR_1_mean]unemploym  
	* 0.0057 / 0.391 / 0.195

	** g8_pledge (SDTF-MDTF<0)
	test [SDTF_1_mean]g8_pledge = [MDTF4_1_mean]g8_pledge  
	di [SDTF_1_mean]g8_pledge -[MDTF4_1_mean]g8_pledge  
	* -0.0129 / 0.016 / 0.008
	test [SDTF_1_mean]g8_pledge = [UMBR_1_mean]g8_pledge  
	di [SDTF_1_mean]g8_pledge - [UMBR_1_mean]g8_pledge  
	* -0.0025 / 0.727 / 0.363
	test [MDTF4_1_mean]g8_pledge = [UMBR_1_mean]g8_pledge  
	di [MDTF4_1_mean]g8_pledge -[UMBR_1_mean]g8_pledge  
	* 0.0105 / 0.249 / 0.8755

	** global (SDTF-MDTF<0)
	test [SDTF_1_mean]global = [MDTF4_1_mean]global  
	di [SDTF_1_mean]global -[MDTF4_1_mean]global  
	* -0.019 / 0.080 / 0.040
	test [SDTF_1_mean]global = [UMBR_1_mean]global  
	di [SDTF_1_mean]global - [UMBR_1_mean]global  
	* -0.1101 / 0.0000 / 0.000
	test [MDTF4_1_mean]global = [UMBR_1_mean]global  
	di [MDTF4_1_mean]global - [UMBR_1_mean]global  
	* -0.091 / 0.0006 / 0.000

	** FCS (SDTF-MDTF<0)
	test [SDTF_1_mean]FCS = [MDTF4_1_mean]FCS  
	di [SDTF_1_mean]FCS - [MDTF4_1_mean]FCS  
	* -0.0013 / 0.929 / 0.460
	test [SDTF_1_mean]FCS = [UMBR_1_mean]FCS  
	di [SDTF_1_mean]FCS - [UMBR_1_mean]FCS  
	* -0.0626 / 0.006 / 0.003
	test [MDTF4_1_mean]FCS = [UMBR_1_mean]FCS  
	di [MDTF4_1_mean]FCS -[UMBR_1_mean]FCS  
	* -0.0613 / 0.0123 / 0.005

	
* 2) With donor and year FE
quietly reg isDonor $X $ctr if sdtf==1 & execution!="BETF", nocon
est store SDTF_2
	predict isDonorhat4, xb
	g pos4=(isDonorhat4>=0.03355882)
	tab pos4 isDonor if sdtf==1 & execution!="BETF", co  
	* 83.3  59.8
quietly reg isDonor $X $ctr if mdtf4==1 & execution!="BETF", nocon
est store MDTF4_2
	predict isDonorhat5, xb
	g pos5=(isDonorhat5>0.08348268)
	tab pos5 isDonor if mdtf4==1 & execution!="BETF", co  
	* 80.6  62.6
quietly reg isDonor $X $ctr if umbr==1 & execution!="BETF", nocon
est store UMBR_2
	predict isDonorhat6, xb
	g pos6=(isDonorhat6>=0.3237)
	tab pos6 isDonor if umbr==1 & execution!="BETF", co   
	* 79.9  60.0
qui suest SDTF_2 MDTF4_2 UMBR_2, cluster(ccode) ro
est tab SDTF_2 MDTF4_2 UMBR_2, star(.1 .05 .01) b(%7.3f) 
estout SDTF_2 MDTF4_2 UMBR_2, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* ) mlab(,) 

	* Wald tests
	** cova 
	test [SDTF_2_mean]cova = [MDTF4_2_mean]cova  
	di [SDTF_2_mean]cova - [MDTF4_2_mean]cova  
	* 0.0076 / 0.711 / 0.355
	test [SDTF_2_mean]cova = [UMBR_2_mean]cova  
	di [SDTF_2_mean]cova -[UMBR_2_mean]cova  
	* 0.155 / 0.0002 / 0.000
	test [MDTF4_2_mean]cova = [UMBR_2_mean]cova  
	di [MDTF4_2_mean]cova -[UMBR_2_mean]cova  
	* 0.1478 / 0.0008 / 0.000
	
	** MIC
	test [SDTF_2_mean]MIC = [MDTF4_2_mean]MIC  
	di [SDTF_2_mean]MIC -[MDTF4_2_mean]MIC  	
	* 0.027 / 0.843 / 0.422
	test [SDTF_2_mean]MIC = [UMBR_2_mean]MIC  
	di [SDTF_2_mean]MIC -[UMBR_2_mean]MIC  	
	* 0.0862 / 0.0000 / 0.000
	test [MDTF4_2_mean]MIC = [UMBR_2_mean]MIC  
	di [MDTF4_2_mean]MIC -[UMBR_2_mean]MIC  
	* 0.0835 / 0.0007 / 0.000
	
	** unemploym
	test [SDTF_2_mean]unemploym = [MDTF4_2_mean]unemploym  
	di [SDTF_2_mean]unemploym -[MDTF4_2_mean]unemploym  
	* -0.0401 / 0.086 / 0.957
	test [SDTF_2_mean]unemploym = [UMBR_2_mean]unemploym  
	di [SDTF_2_mean]unemploym -[UMBR_2_mean]unemploym  
	* 0.0212 / 0.368 / 0.186
	test [MDTF4_2_mean]unemploym = [UMBR_2_mean]unemploym  
	di [MDTF4_2_mean]unemploym - [UMBR_2_mean]unemploym  
	* 0.0613 / 0.083 / 0.042
	
	** g8_pledge
	test [SDTF_2_mean]g8_pledge = [MDTF4_2_mean]g8_pledge  
	di [SDTF_2_mean]g8_pledge - [MDTF4_2_mean]g8_pledge  
	* -0.007 / 0.3218 / 0.161
	test [SDTF_2_mean]g8_pledge = [UMBR_2_mean]g8_pledge  
	di [SDTF_2_mean]g8_pledge - [UMBR_2_mean]g8_pledge  
	* -0.0261 / 0.008 / 0.004
	test [MDTF4_2_mean]g8_pledge = [UMBR_2_mean]g8_pledge  
	di [MDTF4_2_mean]g8_pledge - [UMBR_2_mean]g8_pledge  
	* -0.0189 / 0.111 / 0.055	

	** global
	test [SDTF_2_mean]global = [MDTF4_2_mean]global  
	di [SDTF_2_mean]global -[MDTF4_2_mean]global  
	* -0.024 / 0.034 / 0.017
	test [SDTF_2_mean]global = [UMBR_2_mean]global  
	di [SDTF_2_mean]global - [UMBR_2_mean]global  
	* -0.1172 / 0.000 / 0.000
	test [MDTF4_2_mean]global = [UMBR_2_mean]global  
	di [MDTF4_2_mean]global - [UMBR_2_mean]global  
	* -0.0934 / 0.001 / 0.000

	** FCS
	test [SDTF_2_mean]FCS = [MDTF4_2_mean]FCS  
	di [SDTF_2_mean]FCS - [MDTF4_2_mean]FCS  	
	* -0.0025 / 0.839 / 0.419
	test [SDTF_2_mean]FCS = [UMBR_2_mean]FCS  
	di [SDTF_2_mean]FCS -[UMBR_2_mean]FCS  
	* -0.0798 / 0.0014 / 0.0007
	test [MDTF4_2_mean]FCS = [UMBR_2_mean]FCS  
	di [MDTF4_2_mean]FCS -[UMBR_2_mean]FCS  
	* -0.077 / 0.002 / 0.001

	
* 3) With donor and year FE and additional control variables
global resources lgdp lbaid mshare
global capacity admbi researchers R_D icrg cchairTFsec 
global political polWB
quietly reg isDonor $X $resources $capacity $political $ctr if sdtf==1 & execution!="BETF", nocon 
est store SDTF_3
	predict isDonorhat7, xb
	g pos7=(isDonorhat7>=0.03355882)
	tab pos7 isDonor if sdtf==1 & execution!="BETF", co  
	* 87.5  43.7
quietly reg isDonor $X $resources $capacity $political $ctr if mdtf4==1 & execution!="BETF", nocon 
est store MDTF4_3
	predict isDonorhat8, xb
	g pos8=(isDonorhat8>=0.08348268)
	tab pos8 isDonor if mdtf4==1 & execution!="BETF", co  
	* 85.3  48.5
quietly reg isDonor $X $resources $capacity $political $ctr if umbr==1 & execution!="BETF", nocon 
est store UMBR_3
	predict isDonorhat9, xb
	g pos9=(isDonorhat9>=0.3237)
	tab pos9 isDonor if umbr==1 & execution!="BETF", co  
	* 81.3  51.1
qui suest SDTF_3 MDTF4_3 UMBR_3, cluster(ccode) ro
estout SDTF_3 MDTF4_3 UMBR_3, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* ) mlab(,) 
estout SDTF_1 MDTF4_1 UMBR_1 SDTF_2 MDTF4_2 UMBR_2 SDTF_3 MDTF4_3 UMBR_3, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I*) mlab(,) order(cova MIC unemploym g8_pledge global FCS lgdp lbaid mshare admbi researchers R_D icrgqog cchairTFsec polWB DonorFE YearFE)

	* Wald tests
	** cova 
	test [SDTF_3_mean]cova = [MDTF4_3_mean]cova  
	di [SDTF_3_mean]cova - [MDTF4_3_mean]cova  
	* -0.0024 / 0.922 / 0.539
	test [SDTF_3_mean]cova = [UMBR_3_mean]cova   
	di [SDTF_3_mean]cova -[UMBR_3_mean]cova   
	* 0.1665 / 0.000 / 0.000
	test [MDTF4_3_mean]cova = [UMBR_3_mean]cova   
	di [MDTF4_3_mean]cova -[UMBR_3_mean]cova   
	* 0.1689 / 0.000 / 0.000
	
	** MIC
	test [SDTF_3_mean]MIC = [MDTF4_3_mean]MIC  
	di [SDTF_3_mean]MIC - [MDTF4_3_mean]MIC  
	*0.009 /  0.600 / 0.300
	test [SDTF_3_mean]MIC = [UMBR_3_mean]MIC  
	di [SDTF_3_mean]MIC -[UMBR_3_mean]MIC  
	* 0.0906 / 0.000 / 0.000
	test [MDTF4_3_mean]MIC = [UMBR_3_mean]MIC  
	di [MDTF4_3_mean]MIC -[UMBR_3_mean]MIC  
	* 0.082 / 0.003 / 0.0015

	** unemploym
	test [SDTF_3_mean]unemploym = [MDTF4_3_mean]unemploym  
	di [SDTF_3_mean]unemploym - [MDTF4_3_mean]unemploym  
	* -0.031 / 0.090 / 0.955
	test [SDTF_3_mean]unemploym = [UMBR_3_mean]unemploym  
	di [SDTF_3_mean]unemploym -[UMBR_3_mean]unemploym 
	* 0.221 / 0.434 / 0.217
	test [MDTF4_3_mean]unemploym = [UMBR_3_mean]unemploym  
	di [MDTF4_3_mean]unemploym -[UMBR_3_mean]unemploym  
	* 0.0531 / 0.166 / 0.083
	
	** g8_pledge
	test [SDTF_3_mean]g8_pledge = [MDTF4_3_mean]g8_pledge  
	di [SDTF_3_mean]g8_pledge -[MDTF4_3_mean]g8_pledge  
	* -0.006 / 0.452 / 0.276
	test [SDTF_3_mean]g8_pledge = [UMBR_3_mean]g8_pledge  
	di [SDTF_3_mean]g8_pledge -[UMBR_3_mean]g8_pledge  
	* -0.0200 / 0.096 / 0.048
	test [MDTF4_3_mean]g8_pledge = [UMBR_3_mean]g8_pledge  
	di [MDTF4_3_mean]g8_pledge -[UMBR_3_mean]g8_pledge  
	* -0.014 / 0.339 / 0.169

	** global
	test [SDTF_3_mean]global = [MDTF4_3_mean]global  
	di [SDTF_3_mean]global - [MDTF4_3_mean]global  
	* -0.030 / 0.012 / 0.006
	test [SDTF_3_mean]global = [UMBR_3_mean]global  
	di [SDTF_3_mean]global -[UMBR_3_mean]global  
	* -0.132 / 0.000 / 0.000
	test [MDTF4_3_mean]global = [UMBR_3_mean]global  
	di [MDTF4_3_mean]global - [UMBR_3_mean]global  
	* -0.102 / 0.001 / 0.000

	** FCS
	test [SDTF_3_mean]FCS = [MDTF4_3_mean]FCS  
	di [SDTF_3_mean]FCS -[MDTF4_3_mean]FCS  
	* -0.011 / 0.427 / 0.214
	test [SDTF_3_mean]FCS = [UMBR_3_mean]FCS  
	di [SDTF_3_mean]FCS -[UMBR_3_mean]FCS  
	* -0.076 / 0.006 / 0.003
	test [MDTF4_3_mean]FCS = [UMBR_3_mean]FCS  
	di [MDTF4_3_mean]FCS - [UMBR_3_mean]FCS  
	* -0.066 / 0.019 / 0.005

* Table 1 (set A)
estout SDTF_1 MDTF4_1 UMBR_1 SDTF_2 MDTF4_2 UMBR_2 SDTF_3 MDTF4_3 UMBR_3, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) mlab(,) order(cova MIC unemploym g8_pledge global FCS lgdp lbaid mshare admbi researchers R_D icrgqog cchairTFsec polWB DonorFE YearFE) drop(_I* _cons)

	
* Balanced-sample regressions
* ---------------------------

* Adapt dependent variables
  gen isDonorSDTF=isDonor
  replace isDonorSDTF=0 if sdtf!=1

  gen isDonorMDTF=isDonor
  replace isDonorMDTF=0 if mdtf4!=1

  gen isDonorUMBR=isDonor
  replace isDonorUMBR=0 if umbr!=1
 

* 1b) All potential funds, relevant independent variables only
quietly reg isDonorSDTF $X if execution!="BETF"
est store SDTF_1b
	predict all1, xb
	g ish1=(all1>=.02527416)
	tab ish1 isDonorSDTF if betf==0, co  
	* 81.7  39.6
quietly reg isDonorMDTF $X if execution!="BETF"
est store MDTF4_1b
	predict all2, xb
	g ish2=(all2>=.01282271)
	tab ish2 isDonorMDTF  if betf==0, co  
	* 74.16  39.0
quietly reg isDonorUMBR $X if execution!="BETF"
est store UMBR_1b
	predict all3, xb
	g ish3=(all3>=.03061458)
	tab ish3 isDonorMDTF if betf==0, co  
	* 51.0  55.2
qui suest SDTF_1b MDTF4_1b UMBR_1b, cluster(ccode) ro
est tab SDTF_1b MDTF4_1b UMBR_1b, star(.1 .05 .01) stats(N N_clust r2_a) b(%7.4f)
estout SDTF_1b MDTF4_1b UMBR_1b, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop() mlab(,) 

	* Wald tests
	** cova 
	test [SDTF_1b_mean]cova = [MDTF4_1b_mean]cova  
	di [SDTF_1b_mean]cova -[MDTF4_1b_mean]cova  
	* -0.009 / 0.2044 / 0.898
	test [SDTF_1b_mean]cova = [UMBR_1b_mean]cova   
	di [SDTF_1b_mean]cova - [UMBR_1b_mean]cova   
	* 0.023 / 0.0000 / 0.000
	test [MDTF4_1b_mean]cova = [UMBR_1b_mean]cova   
	di [MDTF4_1b_mean]cova - [UMBR_1b_mean]cova   
	* 0.032 / 0.0000 / 0.000
	
	** MIC
	test [SDTF_1b_mean]MIC = [MDTF4_1b_mean]MIC  
	di [SDTF_1b_mean]MIC -[MDTF4_1b_mean]MIC  
	* -0.002 / 0.4583 / 0.771
	test [SDTF_1b_mean]MIC = [UMBR_1b_mean]MIC  
	di [SDTF_1b_mean]MIC -[UMBR_1b_mean]MIC  
	* -0.007 / 0.041 / 0.980
	test [MDTF4_1b_mean]MIC = [UMBR_1b_mean]MIC  
	di [MDTF4_1b_mean]MIC - [UMBR_1b_mean]MIC  
	* -0.005 / 0.121 / 0.939
	
	** unemploym
	test [SDTF_1b_mean]unemploym = [MDTF4_1b_mean]unemploym  
	di [SDTF_1b_mean]unemploym - [MDTF4_1b_mean]unemploym  
	* -0.002 / 0.232 / 0.884
	test [SDTF_1b_mean]unemploym = [UMBR_1b_mean]unemploym  
	di [SDTF_1b_mean]unemploym -[UMBR_1b_mean]unemploym  
	* -0.002 / 0.266 / 0.867
	test [MDTF4_1b_mean]unemploym = [UMBR_1b_mean]unemploym  
	di [MDTF4_1b_mean]unemploym -[UMBR_1b_mean]unemploym 
	* -0.0003 / 0.952 / 0.524
	
	** g8_pledge
	test [SDTF_1b_mean]g8_pledge = [MDTF4_1b_mean]g8_pledge  
	di [SDTF_1b_mean]g8_pledge -[MDTF4_1b_mean]g8_pledge  
	* -0.007 / 0.000 / 0.000
	test [SDTF_1b_mean]g8_pledge = [UMBR_1b_mean]g8_pledge  
	di [SDTF_1b_mean]g8_pledge -[UMBR_1b_mean]g8_pledge  
	* -0.010 / 0.000 / 0.000
	test [MDTF4_1b_mean]g8_pledge = [UMBR_1b_mean]g8_pledge  
	di [MDTF4_1b_mean]g8_pledge -[UMBR_1b_mean]g8_pledge  
	* -0.003 / 0.040 / 0.020

	** global
	test [SDTF_1b_mean]global = [MDTF4_1b_mean]global  
	di [SDTF_1b_mean]global - [MDTF4_1b_mean]global  
	* -0.016 / 0.010 / 0.005
	test [SDTF_1b_mean]global = [UMBR_1b_mean]global  
	di [SDTF_1b_mean]global -[UMBR_1b_mean]global  
	* -0.067 / 0.0000 / 0.000
	test [MDTF4_1b_mean]global = [UMBR_1b_mean]global  
	di [MDTF4_1b_mean]global -[UMBR_1b_mean]global  
	* -0.051 / 0.0000 / 0.000

	** FCS
	test [SDTF_1b_mean]FCS = [MDTF4_1b_mean]FCS  
	di [SDTF_1b_mean]FCS -[MDTF4_1b_mean]FCS  
	* -0.014 / 0.041 / 0.020
	test [SDTF_1b_mean]FCS = [UMBR_1b_mean]FCS  
	di [SDTF_1b_mean]FCS -[UMBR_1b_mean]FCS  
	* -0.032 / 0.0000 / 0.000
	test [MDTF4_1b_mean]FCS = [UMBR_1b_mean]FCS  
	di [MDTF4_1b_mean]FCS -[UMBR_1b_mean]FCS  
	* -0.018 / 0.0000 / 0.000

	
* 2b) All potential funds, with donor and year FE
quietly reg isDonorSDTF $X $ctr if execution!="BETF", nocon
est store SDTF_2b
	predict all4, xb
	g ish4=(all4>=.02527416)
	tab ish4 isDonorSDTF if betf==0, co  
	* 83.5  60.3
quietly reg isDonorMDTF $X $ctr if execution!="BETF", nocon
est store MDTF4_2b
	predict all5, xb
	g ish5=(all5>=.01282271)
	tab ish5 isDonorMDTF if betf==0, co  
	* 87.5  50.0
quietly reg isDonorUMBR $X $ctr if execution!="BETF", nocon
est store UMBR_2b
	predict all6, xb
	g ish6=(all6>=.03061458)
	tab ish6 isDonorMDTF if betf==0, co  
	* 71.9  48.0
qui suest SDTF_2b MDTF4_2b UMBR_2b, cluster(ccode) ro
est tab SDTF_2b MDTF4_2b UMBR_2b, star(.1 .05 .01) b(%7.3f) 
estout SDTF_2b MDTF4_2b UMBR_2b, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* ) mlab(,) 
estout SDTF_2b MDTF4_2b UMBR_2b, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* ) mlab(,) 

	* Wald tests
	** cova (p-value)
	test [SDTF_2b_mean]cova = [MDTF4_2b_mean]cova  
	di [SDTF_2b_mean]cova -[MDTF4_2b_mean]cova  
	* -0.006 / 0.2045 / 0.898
	test [SDTF_2b_mean]cova = [UMBR_2b_mean]cova    
	di [SDTF_2b_mean]cova -[UMBR_2b_mean]cova    
	* 0.019 / 0.0000 / 0.0000
	test [MDTF4_2b_mean]cova = [UMBR_2b_mean]cova  
	di [MDTF4_2b_mean]cova - [UMBR_2b_mean]cova  
	* 0.025 / 0.0000 / 0.000
	
	** MIC
	test [SDTF_2b_mean]MIC = [MDTF4_2b_mean]MIC  
	di [SDTF_2b_mean]MIC -[MDTF4_2b_mean]MIC  
	* -0.003 / 0.4613 / 0.769
	test [SDTF_2b_mean]MIC = [UMBR_2b_mean]MIC  
	di [SDTF_2b_mean]MIC -[UMBR_2b_mean]MIC  
	* -0.006 / 0.0413 / 0.980
	test [MDTF4_2b_mean]MIC = [UMBR_2b_mean]MIC  
	di [MDTF4_2b_mean]MIC -[UMBR_2b_mean]MIC  
	* -0.004 / 0.1205 / 0.939
	
	** unemploym
	test [SDTF_2b_mean]unemploym = [MDTF4_2b_mean]unemploym  
	di [SDTF_2b_mean]unemploym - [MDTF4_2b_mean]unemploym  
	* -0.003 / 0.506 / 0.750
	test [SDTF_2b_mean]unemploym = [UMBR_2b_mean]unemploym  
	di [SDTF_2b_mean]unemploym -[UMBR_2b_mean]unemploym  
	* 0.005 / 0.2096 / 0.105
	test [MDTF4_2b_mean]unemploym = [UMBR_2b_mean]unemploym  
	di [MDTF4_2b_mean]unemploym -[UMBR_2b_mean]unemploym  
	* 0.008 / 0.2088 / 0.104
	
	** g8_pledge
	test [SDTF_2b_mean]g8_pledge = [MDTF4_2b_mean]g8_pledge  
	di [SDTF_2b_mean]g8_pledge -[MDTF4_2b_mean]g8_pledge  
	* -0.005 / 0.0000 / 0.000
	test [SDTF_2b_mean]g8_pledge = [UMBR_2b_mean]g8_pledge  
	di [SDTF_2b_mean]g8_pledge -[UMBR_2b_mean]g8_pledge  
	* -0.010 / 0.0000 / 0.000
	test [MDTF4_2b_mean]g8_pledge = [UMBR_2b_mean]g8_pledge  
	di [MDTF4_2b_mean]g8_pledge -[UMBR_2b_mean]g8_pledge  
	* -0.005 / 0.0385 / 0.019

	** global
	test [SDTF_2b_mean]global = [MDTF4_2b_mean]global  
	di [SDTF_2b_mean]global -[MDTF4_2b_mean]global  
	* -0.015 / 0.0103 / 0.005
	test [SDTF_2b_mean]global = [UMBR_2b_mean]global  
	di [SDTF_2b_mean]global - [UMBR_2b_mean]global  
	* -0.068 / 0.0000 / 0.000
	test [MDTF4_2b_mean]global = [UMBR_2b_mean]global  
	di [MDTF4_2b_mean]global -[UMBR_2b_mean]global  
	* -0.053 / 0.0000 / 0.000

	** FCS
	test [SDTF_2b_mean]FCS = [MDTF4_2b_mean]FCS  
	di [SDTF_2b_mean]FCS -[MDTF4_2b_mean]FCS  
	* -0.013 / 0.0415 / 0.021
	test [SDTF_2b_mean]FCS = [UMBR_2b_mean]FCS  
	di [SDTF_2b_mean]FCS -[UMBR_2b_mean]FCS  
	* -0.032 / 0.0000 / 0.000
	test [MDTF4_2b_mean]FCS = [UMBR_2b_mean]FCS  
	di [MDTF4_2b_mean]FCS -[UMBR_2b_mean]FCS  
	* -0.019 / 0.0000 / 0.000


* 3b) All potential funds, with donor and year FE and additional control variables
quietly reg isDonorSDTF $X $resources $capacity $political $ctr if execution!="BETF", nocon 
est store SDTF_3b
	predict all7, xb
	g ish7=(all7>=.02527416)
	tab ish7 isDonorSDTF if betf==0, co  
	* 87.9  45.0
quietly reg isDonorMDTF $X $resources $capacity $political $ctr if execution!="BETF", nocon 
est store MDTF4_3b
	predict all8, xb
	g ish8=(all8>=.01282271)
	tab ish8 isDonorMDTF if betf==0, co  
	* 90.4  38.6
quietly reg isDonorUMBR $X $resources $capacity $political $ctr if execution!="BETF", nocon 
est store UMBR_3b
	predict all9, xb
	g ish9=(all9>=.03061458)
	tab ish9 isDonorMDTF if betf==0, co  
	* 77.5  36.9
qui suest SDTF_3b MDTF4_3b UMBR_3b, cluster(ccode) ro
est tab SDTF_3b MDTF4_3b UMBR_3b, star(.1 .05 .01) b(%7.3f) 
estout SDTF_1b MDTF4_1b UMBR_1b SDTF_2b MDTF4_2b UMBR_2b SDTF_3b MDTF4_3b UMBR_3b, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* ) mlab(,) order(cova MIC unemploym g8_pledge global FCS lgdp lbaid mshare admbi researchers R_D icrgqog cchairTFsec polWB DonorFE YearFE)
estout SDTF_3b MDTF4_3b UMBR_3b, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* ) mlab(,) order(cova MIC unemploym g8_pledge global FCS lgdp lbaid mshare admbi researchers R_D icrgqog cchairTFsec polWB DonorFE YearFE)

	* Wald tests
	** cova 
	test [SDTF_3b_mean]cova = [MDTF4_3b_mean]cova  
	di [SDTF_3b_mean]cova - [MDTF4_3b_mean]cova  
	* -0.008 / 0.3692 / 0.816
	test [SDTF_3b_mean]cova = [UMBR_3b_mean]cova  
	di [SDTF_3b_mean]cova -[UMBR_3b_mean]cova  
	* 0.018 / 0.0197 / 0.006
	test [MDTF4_3b_mean]cova = [UMBR_3b_mean]cova 	
	di [MDTF4_3b_mean]cova -[UMBR_3b_mean]cova 	
	* 0.026 / 0.0000 / 0.000
	
	** MIC
	test [SDTF_3b_mean]MIC = [MDTF4_3b_mean]MIC  
	di [SDTF_3b_mean]MIC - [MDTF4_3b_mean]MIC  
	* -0.003 / 0.6024 / 0.700
	test [SDTF_3b_mean]MIC = [UMBR_3b_mean]MIC  
	di [SDTF_3b_mean]MIC -[UMBR_3b_mean]MIC  
	* -0.003 / 0.3897 / 0.981
	test [MDTF4_3b_mean]MIC = [UMBR_3b_mean]MIC 
	di [MDTF4_3b_mean]MIC -[UMBR_3b_mean]MIC 
	* -0.001 / 0.6938 / 0.653
	
	** unemploym
	test [SDTF_3b_mean]unemploym = [MDTF4_3b_mean]unemploym  
	di [SDTF_3b_mean]unemploym -[MDTF4_3b_mean]unemploym  
	* -0.002 / 0.7219 / 0.639
	test [SDTF_3b_mean]unemploym = [UMBR_3b_mean]unemploym  
	di [SDTF_3b_mean]unemploym - [UMBR_3b_mean]unemploym  
	* 0.009 / 0.1106 / 0.055
	test [MDTF4_3b_mean]unemploym = [UMBR_3b_mean]unemploym  
	di [MDTF4_3b_mean]unemploym -[UMBR_3b_mean]unemploym  
	* 0.011 / 0.2278 / 0.114
	
	** g8_pledge
	test [SDTF_3b_mean]g8_pledge = [MDTF4_3b_mean]g8_pledge  
	di [SDTF_3b_mean]g8_pledge -[MDTF4_3b_mean]g8_pledge  
	* -0.005 / 0.0005 / 0.000
	test [SDTF_3b_mean]g8_pledge = [UMBR_3b_mean]g8_pledge  
	di [SDTF_3b_mean]g8_pledge -[UMBR_3b_mean]g8_pledge  
	* -0.011 / 0.0000 / 0.000
	test [MDTF4_3b_mean]g8_pledge = [UMBR_3b_mean]g8_pledge 
	di [MDTF4_3b_mean]g8_pledge -[UMBR_3b_mean]g8_pledge 
	* -0.006 / 0.012 / 0.005

	** global
	test [SDTF_3b_mean]global = [MDTF4_3b_mean]global  
	di [SDTF_3b_mean]global -[MDTF4_3b_mean]global  
	* -0.017 / 0.0103 / 0.005
	test [SDTF_3b_mean]global = [UMBR_3b_mean]global  
	di [SDTF_3b_mean]global -[UMBR_3b_mean]global  
	* -0.076 / 0.0000 / 0.000
	test [MDTF4_3b_mean]global = [UMBR_3b_mean]global  
	di [MDTF4_3b_mean]global - [UMBR_3b_mean]global  
	* -0.060 / 0.0000 / 0.000

	** FCS
	test [SDTF_3b_mean]FCS = [MDTF4_3b_mean]FCS  
	di [SDTF_3b_mean]FCS -[MDTF4_3b_mean]FCS  
	* -0.017 / 0.0127 / 0.005
	test [SDTF_3b_mean]FCS = [UMBR_3b_mean]FCS  
	di [SDTF_3b_mean]FCS -[UMBR_3b_mean]FCS  
	* -0.031 / 0.0000  / 0.005
	test [MDTF4_3b_mean]FCS = [UMBR_3b_mean]FCS  
	di [MDTF4_3b_mean]FCS -[UMBR_3b_mean]FCS  
	* -0.015 / 0.0004 / 0.005

* Table 2 (choice set B)
estout SDTF_1b MDTF4_1b UMBR_1b SDTF_2b MDTF4_2b UMBR_2b SDTF_3b MDTF4_3b UMBR_3b, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) mlab(,) order(cova MIC unemploym g8_pledge global FCS lgdp lbaid mshare admbi researchers R_D icrgqog cchairTFsec polWB DonorFE YearFE) drop(_I* _cons)

	
	
* Robustness checks with other operationalization of fund types
* -------------------------------------------------------------

* Choice set A, no FE
quietly reg isDonor $X if sdtf==1 & execution!="BETF"
est store SDTF_A
quietly reg isDonor $X if mdtf6==1 & execution!="BETF"
est store MDTF6_A
quietly reg isDonor $X if umbr7==1 & execution!="BETF"
est store UMBR7_A
quietly reg isDonor $X if mdtf10==1 & execution!="BETF"
est store MDTF10_A
quietly reg isDonor $X if umbr11==1 & execution!="BETF"
est store UMBR11_A
qui suest SDTF_A MDTF6_A UMBR7_A MDTF10_A UMBR11_A, cluster(ccode) ro
est tab SDTF_A MDTF6_A UMBR7_A MDTF10_A UMBR11_A, star(.1 .05 .01) stats(N N_clust r2_a) b(%7.3f)
estout  SDTF_A MDTF6_A UMBR7_A MDTF10_A UMBR11_A, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_cons) mlab(,) 
	
* Choice set A, FE
quietly reg isDonor $X $ctr if sdtf==1 & execution!="BETF"
est store SDTF_AF
	predict rothr1, xb
	g isrothr1=(rothr1>=.03358379)
	tab isrothr1 isDonor if sdtf==1 & execution!="BETF", co 
	* 83.3  59.8
quietly reg isDonor $X $ctr if mdtf6==1 & execution!="BETF"
est store MDTF6_AF
	predict rothr2, xb
	g isrothr2=(rothr2>=.09748134)
	tab isrothr2 isDonor if mdtf6==1 & execution!="BETF", co  
	* 77.7  63.6
quietly reg isDonor $X $ctr if umbr7==1 & execution!="BETF"
est store UMBR7_AF
	predict rothr3, xb
	g isrothr3=(rothr3>=.40053763)
	tab isrothr3 isDonor if umbr7==1 & execution!="BETF", co  
	* 76.7  63.7
quietly reg isDonor $X $ctr if mdtf10==1 & execution!="BETF"
est store MDTF10_AF
	predict rothr4, xb
	g isrothr4=(rothr4>=.12473461)
	tab isrothr4 isDonor if mdtf10==1 & execution!="BETF", co  
	* 77.7  62.9
quietly reg isDonor $X $ctr if umbr11==1 & execution!="BETF"
est store UMBR11_AF
	predict rothr5, xb
	g isrothr5=(rothr5>=.51507092)
	tab isrothr5 isDonor if umbr11==1 & execution!="BETF", co  
	* 78.0  68.7
qui suest SDTF_AF MDTF6_AF UMBR7_AF MDTF10_AF UMBR11_AF, cluster(ccode) ro
est tab SDTF_AF MDTF6_AF UMBR7_AF MDTF10_AF UMBR11_AF, star(.1 .05 .01) stats(N N_clust r2_a) b(%7.3f)

* Table 6 (Appendix)
estout  SDTF_AF MDTF6_AF UMBR7_AF MDTF10_AF UMBR11_AF, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* _cons) mlab(,) 


* Choice set B, no FE

g isDonorMDTFb=isDonorMDTF
g isDonorUMBRb=isDonorUMBR

replace isDonorSDTF=0 if sdtf!=1
replace isDonorMDTF=0 if mdtf6!=1
replace isDonorMDTFb=0 if mdtf10!=1
replace isDonorUMBR=0 if umbr7!=1
replace isDonorUMBRb=0 if umbr11!=1

quietly reg isDonorSDTF $X if execution!="BETF"
est store SDTF_B
quietly reg isDonorMDTF $X if execution!="BETF"
est store MDTF6_B
quietly reg isDonorUMBR $X if execution!="BETF"
est store UMBR7_B
quietly reg isDonorMDTFb $X if execution!="BETF"
est store MDTF10_B
quietly reg isDonorUMBRb $X if execution!="BETF"
est store UMBR11_B
qui suest SDTF_B MDTF6_B UMBR7_B MDTF10_B UMBR11_B, cluster(ccode) ro
est tab SDTF_B MDTF6_B UMBR7_B MDTF10_B UMBR11_B, star(.1 .05 .01) stats(N N_clust r2_B) b(%7.3f)
estout  SDTF_B MDTF6_B UMBR7_B MDTF10_B UMBR11_B, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_cons) mlab(,) 
	
* Choice set B, FE
quietly reg isDonorSDTF $X $ctr if execution!="BETF"
est store SDTF_BF
	predict rothr6, xb
	g isrothr6=(rothr6>=.0253)
	tab isrothr6 isDonorSDTF if execution!="BETF", co   
	* 83.5  60.3
quietly reg isDonorMDTF $X $ctr if execution!="BETF"
est store MDTF6_BF
	predict rothr7, xb
	g isrothr7=(rothr7>=.0128)
	tab isrothr7 isDonorMDTF if execution!="BETF", co  
	* 87.5  49.9
quietly reg isDonorUMBR $X $ctr if execution!="BETF"
est store UMBR7_BF
	predict rothr8, xb
	g isrothr8=(rothr8>=.0306)
	tab isrothr8 isDonorUMBR if execution!="BETF", co  
	* 87.5  55.1
quietly reg isDonorMDTFb $X $ctr if execution!="BETF"
est store MDTF10_BF
	predict rothr9, xb
	g isrothr9=(rothr9>=.0128)
	tab isrothr9 isDonorMDTFb if execution!="BETF", co  
	* 87.5  49.9
quietly reg isDonorUMBRb $X $ctr if execution!="BETF"
est store UMBR11_BF
	predict rothr10, xb
	g isrothr10=(rothr10>=.0166)
	tab isrothr10 isDonorUMBRb if execution!="BETF", co  
	* 95.4  49.6
qui suest SDTF_BF MDTF6_BF UMBR7_BF MDTF10_BF UMBR11_BF, cluster(ccode) ro
est tab SDTF_BF MDTF6_BF UMBR7_BF MDTF10_BF UMBR11_BF, star(.1 .05 .01) stats(N N_clust r2_a) b(%7.3f)

* Table 7 (Appendix)
estout  SDTF_BF MDTF6_BF UMBR7_BF MDTF10_BF UMBR11_BF, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* _cons) mlab(,) 


* Robustness check: Conditional logit (available on request)

* Sample A
logit isDonor $X $ctr if sdtf==1 & execution!="BETF", nolog vce(cl ccode)
	est store clo1
	lroc, nograph  
	*0.822
logit isDonor $X $ctr if mdtf4==1 & execution!="BETF", nolog vce(cl ccode)
	est store clo2
	lroc, nograph  
	* 0.795
logit isDonor $X $ctr if umbr==1 & execution!="BETF", nolog vce(cl ccode)
	est store clo3
	lroc, nograph  
	* 0.779
est tab clo1 clo2 clo3, star(.1 .05 .01) stats(N area) b(%7.3f)
estout clo1 clo2 clo3, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N area, fmt(%7.0g %7.2f)) drop(_I* _cons) mlab(,) 

* Sample B
logit isDonorSDTF $X $ctr if execution!="BETF", nolog vce(cl ccode)
	est store clo4
	lroc, nograph 
	* 0.825
logit isDonorMDTF $X $ctr if execution!="BETF", nolog vce(cl ccode)
	est store clo5
	lroc, nograph  
	* 0.798
logit isDonorUMBR $X $ctr if execution!="BETF", nolog vce(cl ccode)
	est store clo6
	lroc, nograph 
	* 0.799
estout clo4 clo5 clo6, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N area, fmt(%7.0g %7.2f)) drop(_I* _cons) mlab(,) 


* Descriptive statistics
* ---------------------------

* Table 8 (Appendix)
estpost summarize isDonor isDonorSDTF isDonorMDTF isDonorUMBR $X $resources $capacity $political 
esttab, cells("count(fmt(%9.0f)) mean(fmt(%9.2f)) sd(fmt(%9.2f)) min(fmt(%9.2f)) max(fmt(%9.2f))") style(tex) label


* Online Appendix
* -----------------------------------------------------------------------------------

* Categorization approach
* -----------------------

* Sample A - FE
qui reg isDonor $X $ctr if sdtfeff==1 & betf!=1, nocon 
est store SDTF_1
qui reg isDonor $X $ctr if mdtf4eff==1 & betf!=1, nocon 
est store MDTF4_1
qui reg isDonor $X $ctr if umbreff==1 & betf!=1, nocon 
est store UMBR_1
qui suest SDTF_1 MDTF4_1 UMBR_1, cluster(ccode) ro

estout SDTF_1 MDTF4_1 UMBR_1, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* ) mlab(,) 


* Sample B

* Adapt dependent variables
gen isDonorSDTFeff=isDonor
replace isDonorSDTFeff=0 if sdtfeff!=1

gen isDonorMDTFeff=isDonor
replace isDonorMDTFeff=0 if mdtf4eff!=1

gen isDonorUMBReff=isDonor
replace isDonorUMBReff=0 if umbreff!=1

quietly reg isDonorSDTFeff $X $ctr if execution!="BETF"
est store SDTF_1b
quietly reg isDonorMDTFeff $X $ctr if execution!="BETF"
est store MDTF4_1b
quietly reg isDonorUMBReff $X $ctr if execution!="BETF"
est store UMBR_1b
qui suest SDTF_1b MDTF4_1b UMBR_1b, cluster(ccode) ro

estout SDTF_1b MDTF4_1b UMBR_1b, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I*) mlab(,) 

* Table 1 ('neff' to categorize funds)
estout SDTF_1 MDTF4_1 UMBR_1 SDTF_1b MDTF4_1b UMBR_1b, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* _cons) mlab(,) 


* Control variable approach 
* -------------------------

replace neff=1 if nall==1
g powerd=neff/nall
lab var powerd "Power differential"

qui reg isDonor powerd $X $ctr if sdtf==1 & betf!=1, nocon 
est store SDTF_1
qui reg isDonor powerd $X $ctr if mdtf4==1 & betf!=1,nocon 
est store MDTF4_1
qui reg isDonor powerd $X $ctr if umbr==1 & betf!=1, nocon 
est store UMBR_1
qui suest SDTF_1 MDTF4_1 UMBR_1, cluster(ccode) ro

estout SDTF_1 MDTF4_1 UMBR_1, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* ) mlab(,) 

quietly reg isDonorSDTF powerd $X $ctr if execution!="BETF"
est store SDTF_1b
quietly reg isDonorMDTF powerd $X $ctr if execution!="BETF"
est store MDTF4_1b
quietly reg isDonorUMBR powerd $X $ctr if execution!="BETF"
est store UMBR_1b
qui suest SDTF_1b MDTF4_1b UMBR_1b, cluster(ccode) ro

estout SDTF_1b MDTF4_1b UMBR_1b, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I*) mlab(,) 


* Table 2 (power asymmetry as control variable)
estout SDTF_1 MDTF4_1 UMBR_1 SDTF_1b MDTF4_1b UMBR_1b, style(tex) starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%7.3f)) se(par)) stats(N r2_a, fmt(%7.0g %7.2f)) drop(_I* _cons) mlab(,) 
